.. _all-salt.pillars:

============================
Full list of builtin pillars
============================

.. currentmodule:: salt.pillar

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    cmd_yaml
    hiera
    mongo
    pillar_ldap
